//-----------------------------------------------------------------------------
// This file holds all custom weapon stuffs. Feel free to make your own.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Base Template
//-----------------------------------------------------------------------------
function CW_Stats_Example_Function(weapon, player) //The name of your function that calls stats. Must include `function` `(weapon, player)`!!
{
//Our stats on the weapon. A full list of stats found on the Official TF2Wiki.
	weapon.AddAttribute("damage bonus", 1.25, -1)	//increases our damage by 25%.
	weapon.AddAttribute("max health additive penalty", -25, -1)	//reduces our health by 25.
	
//Our stats on the player.	
	player.AddCustomAttribute("move speed penalty", 0.9, -1) //reduces speed by 10%.
}
//-----------------------------------------------------------------------------
// Registering a weapon
//-----------------------------------------------------------------------------
	RegisterCustomWeapon("my custom weapon", "Saxxy", CW_Stats_Example_Function, "custom_weapon_model", "custom_arms_model", "custom_extra_wearable")
/*	"my custom weapon"
		The weapon's name. Can be any string. Use this for GiveWeapon. (i.e. hPlayer.GiveWeapon("my custom weapon")
	"Saxxy"
		Weapon base. Accepts weapon string name (i.e. "Brass Beast"), item ID (i.e. 312), or handle.
	CW_Stats_Example_Function
		The name of the stats. The function runes when the weapon is given.
	"custom_weapon_model"
		Optional. Model for your custom weapon. Use a model path.
		Pass `null` if it has no custom model.
	"custom_arms_model"
		Optional. The arm animations the tfclass uses. 
		Model path list in `give_tf_weapon.nut` under `enum GTFW_ARMS`.
	"custom_extra_wearable"
		Optional. Extra wearable the tfclass equips, like a Banner backpack or shield. 
*/
//-----------------------------------------------------------------------------
// Example weapon #1. This one is the Scout's Medieval Crossbow.
// It is based off the Crusader's Crossbow. Main stat thing is it slows the player while reloading.
//-----------------------------------------------------------------------------
function CW_Stats_Example_Scout_Medieval_Crossbow(weapon, player)
{
	weapon.AddAttribute("override projectile type", 8, -1)	//shoots Huntsman arrows (that headshot!)
	weapon.AddAttribute("damage penalty", 0.67, -1)		//reduces damage dealt
	weapon.AddAttribute("maxammo primary reduced", 0.11, -1)	//reduces primary ammo
	NetProps.SetPropIntArray(player, "localdata.m_iAmmo", 15, 1)	//sets reserve ammo of primary ammo type to 15
	weapon.AddAttribute("clip size upgrade atomic", 2, -1)	//increases max clipsize by +2
	weapon.SetClip1(3)	//sets clip to 3
	
//This is a think script. What it does is constantly runs in the background, checking for what ever we put in it.
	if( weapon.ValidateScriptScope() )
	{
		const THINK_SCOUTWEAPONRELOAD_DELAY = 0.25	//delay. Place at the end after `return` to change delay time. Default is 0.1.
		
		local entityscript = weapon.GetScriptScope()
		entityscript["think_SlowPlayerDuringReload"] <- function()	//Our script's name.
		{
			if ( NetProps.GetPropInt(weapon, "m_iReloadMode") == 2)	//if we are reloading...
			{
				player.AddCustomAttribute("move speed penalty", 0.67, -1)	//Add attribute that reduces move speed.
			}
			else if ( NetProps.GetPropInt(weapon, "m_iReloadMode") != 2)	//if -not- reloading...
			{
				player.RemoveCustomAttribute("move speed penalty")	//Remove move speed penalty.
			}
			return THINK_SCOUTWEAPONRELOAD_DELAY	//return to top after 0.25 ticks
		}
		AddThinkToEnt(weapon, "think_SlowPlayerDuringReload")	//Adds the think script to handle 'weapon' after it has been validated.
	}
}

//-----------------------------------------------------------------------------
//Registers this weapon as "Kritzader's Crossbow"...
// In this way, we can just use GiveWeapon() to add it to players, without all the hassle!
//-----------------------------------------------------------------------------
	RegisterCustomWeapon("Kritzader's Crossbow", "Crusader's Crossbow", CW_Stats_Example_Scout_Medieval_Crossbow, null, GTFW_ARMS.MEDIC, "models/workshop/player/items/engineer/spr18_cold_case/spr18_cold_case.mdl")




//-----------------------------------------------------------------------------
// Example weapon #2. This one turns you into the Horseless Headless Horsemann.
// It is based off the Demo's Headtaker.
//-----------------------------------------------------------------------------
function CW_Stats_Example_Headless_Hatman(weapon, player)
{
	//player.SetCustomModelWithClassAnimations("models/bots/headless_hatman.mdl") //originally turned player into the actual Horsemann. Changed to use extra_wearable instead!
	NetProps.SetPropInt(player, "m_PlayerClass.m_iClass", 4)	//Forcefully sets tfclass to DEMOMAN
	
//Our stats
	weapon.ReapplyProvision()	//clears any stats cache on weapon
	weapon.AddAttribute("hidden maxhealth non buffed", (player.GetMaxHealth()*10) + 75, -1)	//using this attribute because it can't be overhealed
	player.SetHealth(player.GetMaxHealth())	//set health to max after given maxhealth bonus
	weapon.AddAttribute("move speed bonus", 1.25, -1)	//move speed up
	weapon.AddAttribute("damage bonus", 99, -1)	//instant death
	
	player.Weapon_Switch(weapon)	//vscript built-in function. Forces switch to handle 'weapon'.
	player.AddCond(41)	//locks player in melee
	
//Our effects
	player.SetForcedTauntCam(1)		//sets third person mode
	DoEntFire("!self", "SetModelScale", "1.4", 0, null, player)		//sets player scale
	Convars.SetValue("tf_item_based_forced_holiday", 2)		//sets holiday to use Halloween cosmetics
	player.AddCustomAttribute("SPELL: set Halloween footstep type", 2, -1)	//enables Horseless Horseshoes spell walk flames
	player.AddCustomAttribute("set item tint RGB", 9109759, -1)		//sets tint for Horseless Horseshoes
	
// Deletes all cosmetics from the player
	for (local i = 0; i < 42; i++)
	{
		local wearable = Entities.FindByClassname(null, "tf_*")

		if ( wearable != null && wearable.GetOwner() == player && wearable.GetClassname() != "tf_weapon_sword" && wearable.GetClassname() != "tf_viewmodel" && wearable.Name() != "tf_wearable_vscript" )
		{
			printl(wearable)
			wearable.Kill()
		}
		else
		{
			break
		}
	}
}

//-----------------------------------------------------------------------------
// Using an enum for define model paths
//-----------------------------------------------------------------------------
/* You can use an enum like this to create shortcuts for your coding. */
enum GTFW_MODELS_CUSTOM_WEAPONS
{
	HHH_BIGAXE		= "models/weapons/c_models/c_bigaxe/c_bigaxe.mdl",	//Horsemann's REAL Headtaker
	HHH_BIGMALLET		= "models/weapons/c_models/c_big_mallet/c_big_mallet.mdl", //Horsemann's Mallet
}
//-----------------------------------------------------------------------------
// Precaching models
//-----------------------------------------------------------------------------
//PrecacheModel("models/weapons/c_models/c_bigaxe/c_bigaxe.mdl")
//PrecacheModel("models/weapons/c_models/c_big_mallet/c_big_mallet.mdl")

//Use this function to precache models, so the game preloads them and doesn't crash.
//Not needed if using SetModelSimple function (which precaches for you)

//-----------------------------------------------------------------------------
//Registers this weapon as "Hell-Maker"...
//-----------------------------------------------------------------------------
	RegisterCustomWeapon("Hell-Maker", "HHHH", CW_Stats_Example_Headless_Hatman, GTFW_MODELS_CUSTOM_WEAPONS.HHH_BIGMALLET, null, "models/bots/headless_hatman.mdl")




//-----------------------------------------------------------------------------
// Example weapon #3. This Hot Hand variant lets you shoot fireballs by taunting!
//-----------------------------------------------------------------------------
function CW_Stats_Example_Hottest_Hand(weapon, player)
{
	weapon.AddAttribute("special taunt", 1, -1) //Makes sure that Halloween holiday can't make us not use the taunt kill+fireball.
	
//Function to create a fireball, but only usable from within CW_Stats_Example_Hottest_Hand
	CTFPlayer.ShootFireball <- function()
	{
		local fireball = Entities.CreateByClassname("tf_projectile_spellfireball")
		
		fireball.SetOwner(this)
		NetProps.SetPropInt(fireball, "m_iTeamNum", this.GetTeam())
		fireball.SetLocalOrigin(this.EyePosition()+(this.EyeAngles().Forward()*32) + Vector(0,0,-16))
		fireball.SetLocalAngles(this.EyeAngles())
		fireball.SetAbsVelocity(this.EyeAngles().Forward()*600)

		Entities.DispatchSpawn(fireball)
	}
	
//Uses a think script to check for when the Pyro is 1) Has the HotHand and 2) Is taunting
	if( weapon.ValidateScriptScope() )
	{
		local wep = null
		local CAN_TAUNT_WITH_HOTHAND = false
	
		local entityscript = weapon.GetScriptScope()
		entityscript["think_PyroHottestHand"] <- function()	//Our script's name.
		{
			if ( player.InCond(7) && CAN_TAUNT_WITH_HOTHAND ) {	//IF taunting and while CAN_TAUNT_WITH_HOTHAND is True...
				CAN_TAUNT_WITH_HOTHAND = false
				wep = null
				
				DoEntFire("!self", "RunScriptCode", "self.ShootFireball()", 1.9, null, player)
			}
			else if ( !player.InCond(7) && player.GetActiveWeapon() != wep )	// if player switches weapons...
			{
				wep = player.GetActiveWeapon()	//...make it so they don't run this condition again!
				
				if ( player.GetActiveWeapon().GetClassname() == "tf_weapon_slap" ) {	//if player is holding the hothand...
					CAN_TAUNT_WITH_HOTHAND = true	//...set to true for checking taunting with Hot Hand
				}
			}
			if ( player.GetActiveWeapon().GetClassname() == "tf_weapon_slap" ) {
				player.AddCondEx(37, 0.15, player) //First-blood arena crit-boost. Constantly applies so if the weapon is gone the conditions don't stay.
			}
			else	//if not using Hot Hand
			{
				player.RemoveCond(37)
			}
			return	//uses default 0.1 delay
		}
		AddThinkToEnt(weapon, "think_PyroHottestHand")	//Adds the think script to handle 'weapon' after it has been validated.
	}
}

	RegisterCustomWeapon("Hottest Hand", "Hot Hand", CW_Stats_Example_Hottest_Hand, null, null, null)
